@@ -49,6 +49,21 @@ def get_atom_fea_name(structure: Structure) -> List[dict]:
     # return [i.species.to_dict() for i in structure.sites]
 
 
+def get_ion_fea_name(structure: Structure) -> List[dict]:
+    """
+    For a structure return the list of dictionary for the site occupancy
+    for example, Fe0.5Ni0.5 site will be returned as {"Fe2+": 0.5, "Ni2+": 0.5}
+
+    Args:
+        structure (Structure): pymatgen Structure with potential site disorder
+
+    Returns:
+        a list of site fraction description
+    """
+
+    return [i.species.to_reduced_dict for i in structure.sites]
+
+
 ##############################################################
 
 class AtomMap(Converter):
@@ -76,9 +91,18 @@ class AtomMap(Converter):
 
 
 class BinaryMap(AtomMap):
-    """Base converter with 2 different search_tp."""
+    """Base converter with 2 different search_tp.
 
-    def __init__(self, search_tp: str = "number", weight: bool = True, **kwargs):
+    """
+
+    def __init__(self, search_tp: str = "number", weight: bool = False, **kwargs):
+        """
+
+        Args:
+            search_tp: (str)
+            weight: (bool) , For true,the same key data are summed together.
+            **kwargs:
+        """
         super().__init__(**kwargs)
         self.search_tp = search_tp
         self.weight = weight
@@ -89,6 +113,10 @@ class BinaryMap(AtomMap):
             if isinstance(d, Structure):
                 d = get_atom_fea_name(d)
             return self.convert_dict(d)
+        elif self.search_tp == "ion_name":
+            if isinstance(d, Structure):
+                d = get_ion_fea_name(d)
+            return self.convert_dict(d)
         else:
             if isinstance(d, Structure):
                 d = get_atom_fea_number(d)
@@ -142,7 +170,7 @@ class AtomJsonMap(BinaryMap):
                 Name of file or dict,element to element vector dictionary
 
                 Provides the pre-trained elemental embeddings using formation energies,
-                which can be used to speed up the training of other models. The embeddings
+                which can be used to speed up the training of other models_geo. The embeddings
                 are also extremely useful elemental descriptors that encode chemical
                 similarity that may be used in other ways.
         """
